@@ -5,7 +5,7 @@
 import time
 import board
 from ulab import numpy as np
-from uplot import Uplot
+from circuitpython_uplot.uplot import Uplot
 
 # Setting up the display
 display = board.DISPLAY
